local mod = MorgDKP2:NewModule("Zerosum")
local L = LibStub("AceLocale-3.0"):GetLocale("MorgDKP2")

local mdkp = MorgDKP2

mod.modName = L["Zerosum DKP"]
mod.modref = "Zerosum"

local Player = UnitName("player")
local db
local fmt = string.format
local floor = math.floor
local tinsert = table.insert
local zeroattends = {}

local defaults = { 
	profile = {
		usewait = nil,
	},
}

function mod:GetOptions()
	return options
end

function mod:IsDKP()
	return true
end

function mod:GetName()
	return mod.modName, mod.modref
end

function mod:OnInitialize()
	self.db = mdkp.db:RegisterNamespace("Zerosum", defaults)
	
end

function mod:OnEnable()
	db = mdkp.db.profile
	db.moduleON["Zerosum"] = true
	
end

function mod:UpdateDB()
	db = mdkp.db.profile
end

function mod:Toggle(info, v)
	mdkp.db.profile.modules.Zerosum = v
	if v then mod:Enable()
	else mod:Disable() end
	self:DKPChange(mod.modName)
end

function mod:SetOpt(info, v)
	local db = mod.db.profile
	local opt = info[#info]
	db[opt] = v
end

function mod:GetOpt(info)
	local db = mod.db.profile
	local opt = info[#info]
	return db[opt]
end

function mod:OnDisable()
	db.moduleON["Zerosum"] = nil
end

function mod:GetPlayerPoints(name, POOL, showearned)
	if not showearned or showearned == 1 then return db.info[name][POOL].points end
	if showearned == 2 then return db.info[name][POOL].earned
	elseif showearned == 3 then return db.info[name][POOL].attend
	end
end

function mod:GetItemValue(itemid, player, POOL)
	local itempoints = db.items[itemid].points
	itempoints = floor(self:GetTAKEModeValue(itemid, itempoints, player) * 100) / 100
	return itempoints
end

function mod:ItemRecorded(id, looter, POOL, points, itempoints, link, attendees, boss)
	if looter == L["Bank"] or not attendees then return end
	points = points - itempoints
	self:AwardItem(id, looter, POOL, points, itempoints, link)
	
	zeroattends = {}
	for _, name in pairs(attendees) do
		tinsert(zeroattends, name)
	end
	
	--add zero sum points
	if itempoints == 0 or not attendees then return end
	if self.db.profile.usewait then
		local waitattends
		local killid = self:GetEventID(2)
		if boss ~= "Trash mob" then killid = #db.raidlog[db.raidnum].bosskills end
		local wait = self:GetModuleRef("Waitlist")
		if wait then waitattends = wait:GetWaitlist() end
		if waitattends then
			for _, name in pairs(waitattends) do
				tinsert(zeroattends, name)
				local found = nil
				for _, inname in pairs(db.raidlog[db.raidnum].bosskills[killid].attendees) do
					if inname == name then
						found = true
						break
					end
				end
				if not found then tinsert(db.raidlog[db.raidnum].bosskills[killid].attendees, name) end
			end
		end
	end
	local addpoints = floor(itempoints / #zeroattends * 100) / 100
	self:AwardDKP(addpoints, 0, POOL, zeroattends)
end

function mod:ItemRebate(id, looter, POOL, itempoints, link, oldattends, newattends, trashadjust, points)
	if newattends then		--changing item event
		--remove points from old attendees
		if oldattends then
			local addpoints = floor(itempoints / #oldattends * 100) / 100 
			self:AwardDKP(0, addpoints, POOL, oldattends)
		end
		
		--add points to new attendees
		if looter == L["Bank"] then return end
		local addpoints = floor(itempoints / #newattends * 100) / 100  
		self:AwardDKP(addpoints, 0, POOL, newattends)
	else
		if trashadjust then
			local addpoints = floor(itempoints / #oldattends * 100) / 100 
			points = points - itempoints
			self:AwardItem(id, looter, POOL, points, itempoints, link)
			self:AwardDKP(addpoints, 0, POOL, oldattends)
		elseif oldattends and looter ~= L["Bank"] then
			local addpoints = floor(itempoints / #oldattends * 100) / 100 
			self:AwardDKP(0, addpoints, POOL, oldattends)
			self:AdjustDKPPoints(looter, looter, POOL, nil, itempoints)
		end
	end
end

function mod:ItemAdjustment(id, looter, POOL, newcost, link, oldcost, attends)
	if not attends or looter == L["Bank"] then return end
	local diff = oldcost - newcost
	local addpoints = floor(diff / #attends * 100) / 100 
	self:AwardDKP(0, addpoints, POOL, attends)
end


function mod:ItemTransfer(id, newmember, oldmember, POOL, newcost, link, oldcost)
	self:AdjustDKPPoints(newmember, oldmember, POOL, newcost, oldcost, link)
end
